@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10552 2017-11-26 08:30:27Z Lavender $
+# $Id: __init__.py 10564 2017-11-28 05:50:02Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2017-11-26 16:30:27 +0800 (週日, 26 十一月 2017) $
-# $Revision: 10552 $
+# $Date: 2017-11-28 13:50:02 +0800 (Tue, 28 Nov 2017) $
+# $Revision: 10564 $
 
 import os
 import warnings
@@ -79,7 +79,7 @@ def attachSettings(settingsDict):
         'Zephyrus.landing',
         'Zephyrus.facebook',
         'drip',
-        'Zephyrus.drip2',
+        'Zephyrus.autoresponder',
     )
 
     installed = settingsDict['INSTALLED_APPS']
