@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: __init__.py 10439 2017-11-05 09:05:24Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-11-05 17:05:24 +0800 (Sun, 05 Nov 2017) $
+# $Revision: 10439 $
 
 import os
 import logging
@@ -48,6 +48,12 @@ FIXTURES_DIR_PATH = os.path.abspath(
 IMAGES_DIR_PATH = os.path.abspath(
     os.path.join('.', 'images')) 
 
+PROJECT_MASHINES_DIR = os.path.join(
+    ROOT_DIR_PATH, "BoilerplateProjects")
+
+PROJECT_MASHINES_ZIP = os.path.join(
+    os.path.dirname(os.path.abspath(__file__)), "ProjectMachine.zip")
+
 def createLogger(name, fileHandlerName):
     logger = logging.getLogger(name)
     logger.setLevel(logging.DEBUG)
