@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: assign_templates.py 10312 2017-09-24 06:53:54Z Lavender $
+# $Id: assign_templates.py 10389 2017-10-22 05:43:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,15 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-24 14:53:54 +0800 (週日, 24 九月 2017) $
-# $Revision: 10312 $
+# $Date: 2017-10-22 13:43:34 +0800 (Sun, 22 Oct 2017) $
+# $Revision: 10389 $
 
 import os
 import shutil
 import random
 import math
 
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 
 from Zephyrus.boilerplate.management.commands import createLogger
 
@@ -57,10 +57,10 @@ class Command(BaseCommand):
 
             random.shuffle(dirs)
             
-            for i, dir in enumerate(dirs, 0):
-                dirPath =  os.path.join(startPath, dir)
+            for i, d in enumerate(dirs, 0):
+                dirPath = os.path.join(startPath, d)
                 dirName = str(math.ceil(float(i + 1) / templateNumber))
-                dst = os.path.join(dstPath, dirName, dir)
+                dst = os.path.join(dstPath, dirName, d)
                 shutil.copytree(dirPath, dst)
 
                 if not notCreateTxt:
