@@ -32,6 +32,9 @@ from BeautifulSoup import (
         Declaration, CData)
 _DECLARATION_OR_DOCTYPE = Declaration
 
+# 因為 lxml 關於使用哪個 BeautifulSoup 來 parse 的機制沒有設計得很完善會有 bug
+# 因此使用 monkey patch 來做
+# 注意: 別 Import 此檔案
 soupparser.BeautifulSoup = BeautifulSoup
 soupparser.Tag = Tag
 soupparser.Comment = Comment
@@ -481,6 +484,16 @@ class Command(BaseCommand):
             head.text = ''
         head.text = '\n' + CMS_HEAD_FRONT_TAG + head.text
 
+        # add cms data to body
+        if body.getchildren():
+            if body[-1].tail is None:
+                body[-1].tail = ''
+            body[-1].tail = body[-1].tail + CMS_BODY_BACK_TAG + '\n'
+            body.text = '\n' + CMS_BODY_FRONT_TAG + body.text
+        else:
+            body.text = CMS_BODY_FRONT_TAG + body.text + \
+                        CMS_BODY_BACK_TAG
+
         # google analytics
         if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
@@ -490,12 +503,12 @@ class Command(BaseCommand):
             # comment
             analyticsComment = etree.Comment(
                 text=get_template(
-                    'boilerplate/txt/analyticsComment.txt').render())
+                    'boilerplate/txt/AnalyticsComment.txt').render())
 
             # iframe
             analyticsIframe = etree.Element('iframe')
             url = get_template(
-                    'boilerplate/txt/analyticsUrl.txt').render()
+                    'boilerplate/txt/AnalyticsUrl.txt').render()
             analyticUrl = \
                 "%s?upc=%s&complexity=CMS_PLUGINIZE_REPLACE" % (url, upc)
 
@@ -514,16 +527,6 @@ class Command(BaseCommand):
             body.append(analyticsComment)
             body.append(analyticsIframe)
 
-        # add cms data to body
-        if body.getchildren():
-            if body[-1].tail is None:
-                body[-1].tail = ''
-            body[-1].tail = body[-1].tail + CMS_BODY_BACK_TAG + '\n'
-            body.text = '\n' + CMS_BODY_FRONT_TAG + body.text
-        else:
-            body.text = CMS_BODY_FRONT_TAG + body.text + \
-                        CMS_BODY_BACK_TAG
-
         # add header legel
         html = page.getroot()
         html.addprevious(legel)
