@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10439 2017-11-05 09:05:24Z Lavender $
+# $Id: pluginize.py 10554 2017-11-26 13:21:13Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-05 17:05:24 +0800 (週日, 05 十一月 2017) $
-# $Revision: 10439 $
+# $Date: 2017-11-26 21:21:13 +0800 (Sun, 26 Nov 2017) $
+# $Revision: 10554 $
 
 import os
 import json
@@ -94,9 +94,10 @@ class Placeholder2(Placeholder):
                 data = json.load(jsonfile)
 
             if 'complexity' in data:
-                data['complexity'] = data['complexity'] + len(placeholders)
+                data['complexity'] = \
+                    data['complexity'] + (len(placeholders) / 2)
             else:
-                data['complexity'] = len(placeholders)
+                data['complexity'] = len(placeholders) / 2
 
             with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
                 line = json.dumps(data)
@@ -308,6 +309,16 @@ class Command(BaseCommand):
                 raise CommandError('%s Complexity = 0' % data['slug'])
             if 'upc' in data:
                 logger.info('UPC : %s' % data['upc'])
+
+            for file in os.listdir(path):
+                file = os.path.join(path, file)
+                with open(file) as f:
+                    content = f.read()
+                content = content.replace(
+                    "complexity=CMS_PLUGINIZE_REPLACE", 
+                    "complexity=%d" % data['complexity'])
+                with open(file, 'w') as f:
+                    f.write(content)
         
         logger.info('DONE!')
         
