@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10567 2017-11-28 07:37:59Z Lavender $
+# $Id: setup.py 10570 2017-11-28 08:48:05Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-28 15:37:59 +0800 (週二, 28 十一月 2017) $
-# $Revision: 10567 $ 
+# $Date: 2017-11-28 16:48:05 +0800 (Tue, 28 Nov 2017) $
+# $Revision: 10570 $ 
 
 import os
 import sys
@@ -216,7 +216,9 @@ if __name__ == "__main__":
             result = os.system("pip install djangocms-installer")
             if result != 0:
                 logger.error(
-                    "Please check network is connect or pip is enable.")
+                    "Unable to run pip, please check your pip configuration, "
+                    "maybe it is because you didn't set python in system PATH "
+                    "or broken network connection.")
                 sys.exit(1)
         
         if sys.version_info.major == 3:
