@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: LandingSocial.py 9976 2017-05-16 06:31:28Z Lavender $
+# $Id: LandingSocial.py 10323 2017-09-26 10:41:04Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,21 +12,24 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
-# $Revision: 9976 $
+# $Date: 2017-09-26 18:41:04 +0800 (Tue, 26 Sep 2017) $
+# $Revision: 10323 $
 
 from django import template
 from django.utils.safestring import mark_safe
 from django.core.urlresolvers import reverse
+from djangocms_forms.utils import int_to_hashid
 
 register = template.Library()
 
 @register.simple_tag
-def LandingSocial(request, method, redirectTo=None):
+def LandingSocial(request, method, redirectTo=None, form=None):
     social = reverse('social:begin', args=[method])
     fromUrl = request.path 
     next = "?next=%s?fromUrl=%s" % (reverse('landing_social'), fromUrl)
     if redirectTo:
         next += ("%26redirectTo=" + redirectTo)
     url = social + next
+    if form:
+        url = url + "%26formId=" + int_to_hashid(form.pk)
     return mark_safe(url)
